# RoleEnum

* `manager` - Manager * `project_manager` - Project Manager * `object_manager` - Object Manager * `dispatcher` - Dispatcher * `driver` - Driver * `acceptor` - Acceptor * `loader_operator` - Loader operator

## Enum

* `MANAGER` (value: `'manager'`)

* `PROJECT_MANAGER` (value: `'project_manager'`)

* `OBJECT_MANAGER` (value: `'object_manager'`)

* `DISPATCHER` (value: `'dispatcher'`)

* `DRIVER` (value: `'driver'`)

* `ACCEPTOR` (value: `'acceptor'`)

* `LOADER_OPERATOR` (value: `'loader_operator'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


